==> jc-1.4.0.tar.gz: soot/toolkits/scalar/UnusedLocalEliminator.h <==
// public class soot.toolkits.scalar.UnusedLocalEliminator

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a76a7734eb62f430 soot_BodyTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class 95c442e1f4de04da soot_toolkits_scalar_UnusedLocalEliminator

// header file dependencies
// @dep_header soot_BodyTransformer

#include "soot/BodyTransformer.h"

#ifndef _JC_soot_toolkits_scalar_UnusedLocalEliminator_H_
#define _JC_soot_toolkits_scalar_UnusedLocalEliminator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Body$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_toolkits_scalar_UnusedLocalEliminator$object;

// Typedefs
typedef struct _jc_soot_toolkits_scalar_UnusedLocalEliminator$sub_refs	_jc_soot_toolkits_scalar_UnusedLocalEliminator$sub_refs;
typedef struct _jc_soot_toolkits_scalar_UnusedLocalEliminator$sub_nonrefs	_jc_soot_toolkits_scalar_UnusedLocalEliminator$sub_nonrefs;
typedef struct _jc_soot_toolkits_scalar_UnusedLocalEliminator$refs	_jc_soot_toolkits_scalar_UnusedLocalEliminator$refs;
typedef struct _jc_soot_toolkits_scalar_UnusedLocalEliminator$nonrefs	_jc_soot_toolkits_scalar_UnusedLocalEliminator$nonrefs;
typedef struct _jc_soot_toolkits_scalar_UnusedLocalEliminator$object	_jc_soot_toolkits_scalar_UnusedLocalEliminator$object;

typedef const struct _jc_soot_toolkits_scalar_UnusedLocalEliminator$vmethods	_jc_soot_toolkits_scalar_UnusedLocalEliminator$vmethods;
typedef const struct _jc_soot_toolkits_scalar_UnusedLocalEliminator$vtable	_jc_soot_toolkits_scalar_UnusedLocalEliminator$vtable;
typedef const struct _jc_soot_toolkits_scalar_UnusedLocalEliminator$vtype	_jc_soot_toolkits_scalar_UnusedLocalEliminator$vtype;

// Constructors
extern void _jc_soot_toolkits_scalar_UnusedLocalEliminator$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_toolkits_scalar_UnusedLocalEliminator$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern void _jc_soot_toolkits_scalar_UnusedLocalEliminator$method$internalTransform$9abd4924859b68a3(_jc_env *, struct _jc_soot_toolkits_scalar_UnusedLocalEliminator$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_toolkits_scalar_UnusedLocalEliminator$method_info$internalTransform$9abd4924859b68a3;

// Static methods
extern struct _jc_soot_toolkits_scalar_UnusedLocalEliminator$object *_jc_soot_toolkits_scalar_UnusedLocalEliminator$method$v$def8fffd7cb356cf(_jc_env *);

// Virtual methods structure
struct _jc_soot_toolkits_scalar_UnusedLocalEliminator$vmethods {
	void	(*internalTransform$9abd4924859b68a3)(_jc_env *, struct _jc_soot_toolkits_scalar_UnusedLocalEliminator$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_toolkits_scalar_UnusedLocalEliminator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_BodyTransformer$vmethods	soot_BodyTransformer;
	_jc_soot_toolkits_scalar_UnusedLocalEliminator$vmethods	soot_toolkits_scalar_UnusedLocalEliminator;
};

// Vtype
struct _jc_soot_toolkits_scalar_UnusedLocalEliminator$vtype {
	_jc_type			type;
	_jc_soot_toolkits_scalar_UnusedLocalEliminator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_UnusedLocalEliminator$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_toolkits_scalar_UnusedLocalEliminator$refs {
    _jc_soot_toolkits_scalar_UnusedLocalEliminator$sub_refs	soot_toolkits_scalar_UnusedLocalEliminator;
    _jc_soot_BodyTransformer$sub_refs	soot_BodyTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_UnusedLocalEliminator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_scalar_UnusedLocalEliminator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_BodyTransformer$sub_nonrefs	soot_BodyTransformer;
    _jc_soot_toolkits_scalar_UnusedLocalEliminator$sub_nonrefs	soot_toolkits_scalar_UnusedLocalEliminator;
};

// Object instance structure
struct _jc_soot_toolkits_scalar_UnusedLocalEliminator$object {
	_jc_soot_toolkits_scalar_UnusedLocalEliminator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_scalar_UnusedLocalEliminator$vtype	*vtype;
	_jc_soot_toolkits_scalar_UnusedLocalEliminator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_scalar_UnusedLocalEliminator$vtype _jc_soot_toolkits_scalar_UnusedLocalEliminator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_scalar_UnusedLocalEliminator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_scalar_UnusedLocalEliminator$class_object;

#endif	/* _JC_soot_toolkits_scalar_UnusedLocalEliminator_H_ */

==> jc-1.4.6.tar.gz: soot/toolkits/scalar/UnusedLocalEliminator.h <==
// public class soot.toolkits.scalar.UnusedLocalEliminator

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a76a7734eb62f430 soot_BodyTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class 95c442e1f4de04da soot_toolkits_scalar_UnusedLocalEliminator

// header file dependencies
// @dep_header soot_BodyTransformer

#include "soot/BodyTransformer.h"

#ifndef _JC_soot_toolkits_scalar_UnusedLocalEliminator_H_
#define _JC_soot_toolkits_scalar_UnusedLocalEliminator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Body$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_toolkits_scalar_UnusedLocalEliminator$object;

// Typedefs
typedef struct _jc_soot_toolkits_scalar_UnusedLocalEliminator$sub_refs	_jc_soot_toolkits_scalar_UnusedLocalEliminator$sub_refs;
typedef struct _jc_soot_toolkits_scalar_UnusedLocalEliminator$sub_nonrefs	_jc_soot_toolkits_scalar_UnusedLocalEliminator$sub_nonrefs;
typedef struct _jc_soot_toolkits_scalar_UnusedLocalEliminator$refs	_jc_soot_toolkits_scalar_UnusedLocalEliminator$refs;
typedef struct _jc_soot_toolkits_scalar_UnusedLocalEliminator$nonrefs	_jc_soot_toolkits_scalar_UnusedLocalEliminator$nonrefs;
typedef struct _jc_soot_toolkits_scalar_UnusedLocalEliminator$object	_jc_soot_toolkits_scalar_UnusedLocalEliminator$object;

typedef const struct _jc_soot_toolkits_scalar_UnusedLocalEliminator$vmethods	_jc_soot_toolkits_scalar_UnusedLocalEliminator$vmethods;
typedef const struct _jc_soot_toolkits_scalar_UnusedLocalEliminator$vtable	_jc_soot_toolkits_scalar_UnusedLocalEliminator$vtable;
typedef const struct _jc_soot_toolkits_scalar_UnusedLocalEliminator$vtype	_jc_soot_toolkits_scalar_UnusedLocalEliminator$vtype;

// Constructors
extern void _jc_soot_toolkits_scalar_UnusedLocalEliminator$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_toolkits_scalar_UnusedLocalEliminator$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_toolkits_scalar_UnusedLocalEliminator$method$internalTransform$9abd4924859b68a3(_jc_env *, struct _jc_soot_toolkits_scalar_UnusedLocalEliminator$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_toolkits_scalar_UnusedLocalEliminator$method_info$internalTransform$9abd4924859b68a3;

// Static methods
extern struct _jc_soot_toolkits_scalar_UnusedLocalEliminator$object *_jc_soot_toolkits_scalar_UnusedLocalEliminator$method$v$def8fffd7cb356cf(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_toolkits_scalar_UnusedLocalEliminator$vmethods {
	void	(*internalTransform$9abd4924859b68a3)(_jc_env *, struct _jc_soot_toolkits_scalar_UnusedLocalEliminator$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_toolkits_scalar_UnusedLocalEliminator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_BodyTransformer$vmethods	soot_BodyTransformer;
	_jc_soot_toolkits_scalar_UnusedLocalEliminator$vmethods	soot_toolkits_scalar_UnusedLocalEliminator;
};

// Vtype
struct _jc_soot_toolkits_scalar_UnusedLocalEliminator$vtype {
	_jc_type			type;
	_jc_soot_toolkits_scalar_UnusedLocalEliminator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_UnusedLocalEliminator$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_toolkits_scalar_UnusedLocalEliminator$refs {
    _jc_soot_toolkits_scalar_UnusedLocalEliminator$sub_refs	soot_toolkits_scalar_UnusedLocalEliminator;
    _jc_soot_BodyTransformer$sub_refs	soot_BodyTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_UnusedLocalEliminator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_scalar_UnusedLocalEliminator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_BodyTransformer$sub_nonrefs	soot_BodyTransformer;
    _jc_soot_toolkits_scalar_UnusedLocalEliminator$sub_nonrefs	soot_toolkits_scalar_UnusedLocalEliminator;
};

// Object instance structure
struct _jc_soot_toolkits_scalar_UnusedLocalEliminator$object {
	_jc_soot_toolkits_scalar_UnusedLocalEliminator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_scalar_UnusedLocalEliminator$vtype	*vtype;
	_jc_soot_toolkits_scalar_UnusedLocalEliminator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_scalar_UnusedLocalEliminator$vtype _jc_soot_toolkits_scalar_UnusedLocalEliminator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_scalar_UnusedLocalEliminator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_scalar_UnusedLocalEliminator$class_object;

#endif	/* _JC_soot_toolkits_scalar_UnusedLocalEliminator_H_ */
